@@ -42,6 +42,20 @@ class Client(object):
         self.close()
 
     def variation(self, experiment_key, user_id, default_variation='A'):
+        """
+        Decide the variation to expose to the user for experiment.
+
+        This method return the "A" if:
+            - The experiment key is invalid
+            - The experiment has not started yet
+            - The user is not allocated to the experiment
+            - The decided variation has been dropped
+
+        :param experiment_key: the unique key of the experiment.
+        :param user_id: the identifier of your customer (e.g. user_email, account_id, etc.) MUST NOT be null.
+        :param default_variation: the default variation of the experiment. MUST NOT be null.
+        :return: the decided variation for the user, or the default variation.
+        """
         if not validator.is_non_zero_and_empty_int(experiment_key):
             self.logger.error('Experiment Key Is Not Empty : {}'.format(experiment_key))
             return default_variation
@@ -71,6 +85,14 @@ class Client(object):
         return default_variation
 
     def track(self, event_key, user_id, value=None):
+        """
+        Records the event performed by the user with additional numeric value.
+
+        :param event_key: the unique key of the event. MUST NOT be null.
+        :param user_id: the identifier of user that performed the event. MUST NOT be null.
+        :param value: additional numeric value of the event (e.g. purchase_amount, api_latency, etc.)
+        :return:
+        """
         if not validator.is_non_empty_string(event_key):
             self.logger.error('Event Key Is Not Empty : {}'.format(event_key))
             return
@@ -81,9 +103,8 @@ class Client(object):
             return
 
         event_type = config.get_event(event_key)
-        if event_type:
-            self.event_processor.process(
-                event.TrackEvent(user_id, event_type.id, event_type.key, value)
-            )
+        self.event_processor.process(
+            event.TrackEvent(user_id, event_type.id, event_type.key, value)
+        )
 
         return
